const _deleteQueryBatch = async (db, query, resolve) => {
  const snapshot = await query.get();
  const batchSize = snapshot.size;
  if (batchSize === 0) {
    resolve();
    return;
  }
  const batch = db.batch();
  snapshot.docs.forEach((doc) => {
    batch.delete(doc.ref);
  });
  await batch.commit();
  // Recurse on the next process tick to avoid exploding the stack
  process.nextTick(() => {
    _deleteQueryBatch(db, query, resolve);
  });
};

export const deleteQueryBatch = async (db, query) => {
  return new Promise((resolve, reject) => {
    _deleteQueryBatch(db, query, resolve).catch(reject);
  });
};
// # sourceMappingURL=firestore.js.map
